@@ -1,4 +1,4 @@
-/* Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2016, 2022, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -166,7 +166,7 @@ int Sasl_client::read_method_name_from_server() {
 }
 
 Sasl_client::Sasl_client() {
-  m_connection = NULL;
+  m_connection = nullptr;
   m_ldap_server_host = "";
   m_mysql = nullptr;
   m_sasl_mechanism = nullptr;
@@ -202,12 +202,12 @@ int Sasl_client::initilize() {
 #endif
   /** Creating sasl connection. */
   if (m_ldap_server_host.empty()) {
-    rc_sasl = sasl_client_new(m_service_name, NULL, NULL, NULL, callbacks, 0,
-                              &m_connection);
+    rc_sasl = sasl_client_new(m_service_name, nullptr, nullptr, nullptr,
+                              callbacks, 0, &m_connection);
   } else {
     log_info(m_ldap_server_host.c_str());
-    rc_sasl = sasl_client_new(m_service_name, m_ldap_server_host.c_str(), NULL,
-                              NULL, callbacks, 0, &m_connection);
+    rc_sasl = sasl_client_new(m_service_name, m_ldap_server_host.c_str(),
+                              nullptr, nullptr, callbacks, 0, &m_connection);
   }
   if (rc_sasl != SASL_OK) {
     log_stream << "Sasl_client::initilize failed rc: " << rc_sasl;
@@ -312,11 +312,11 @@ int Sasl_client::sasl_step(char *server_in, int server_in_length,
   do {
     if (server_in && server_in[0] == 0x0) {
       server_in_length = 0;
-      server_in = NULL;
+      server_in = nullptr;
     }
     rc_sasl = sasl_client_step(
-        m_connection, (server_in == NULL) ? NULL : server_in,
-        (server_in == NULL) ? 0 : server_in_length, &interactions,
+        m_connection, (server_in == nullptr) ? nullptr : server_in,
+        (server_in == nullptr) ? 0 : server_in_length, &interactions,
         static_cast<const char **>(client_out_p),
         (unsigned int *)client_out_length);
     if (rc_sasl == SASL_INTERACT) Sasl_client::interact(interactions);
@@ -422,7 +422,7 @@ static int sasl_authenticate(MYSQL_PLUGIN_VIO *vio, MYSQL *mysql) {
     MySQL server plug-in working as proxy for SASL / LDAP server.
   */
   do {
-    server_packet = NULL;
+    server_packet = nullptr;
     server_packet_len = 0;
     rc_auth = sasl_client.send_sasl_request_to_server(
         (const unsigned char *)sasl_client_output, sasl_client_output_len,
@@ -430,7 +430,7 @@ static int sasl_authenticate(MYSQL_PLUGIN_VIO *vio, MYSQL *mysql) {
     if (rc_auth < 0) {
       goto EXIT;
     }
-    sasl_client_output = NULL;
+    sasl_client_output = nullptr;
     rc_sasl =
         sasl_client.sasl_step((char *)server_packet, server_packet_len,
                               &sasl_client_output, &sasl_client_output_len);
@@ -450,7 +450,7 @@ static int sasl_authenticate(MYSQL_PLUGIN_VIO *vio, MYSQL *mysql) {
       conculded in the client side.
     */
     if (strcmp(sasl_client.get_method().c_str(), SASL_GSSAPI) == 0) {
-      server_packet = NULL;
+      server_packet = nullptr;
       rc_auth = sasl_client.send_sasl_request_to_server(
           (const unsigned char *)sasl_client_output, sasl_client_output_len,
           &server_packet, &server_packet_len);
